========
API Docs
========

Variables
=========

.. automodule:: essm.variables

Chamber
-------

.. automodule:: essm.variables.chamber

Mass
~~~~

.. automodule:: essm.variables.chamber.mass
   :members:

Insulation
~~~~~~~~~~

.. automodule:: essm.variables.chamber.insulation
   :members:

Leaf
----

.. automodule:: essm.variables.leaf

Radiation
~~~~~~~~~

.. automodule:: essm.variables.leaf.radiation
   :members:

Water Vapour
~~~~~~~~~~~~

.. automodule:: essm.variables.leaf.water_vapour
   :members:

Physics
-------

.. automodule:: essm.variables.physics.thermodynamics
   :members:

Units
-----

.. automodule:: essm.variables.units
   :members:

Equations
=========

.. automodule:: essm.equations

Chamber
-------

.. automodule:: essm.equations.chamber

Insulation
~~~~~~~~~~

.. automodule:: essm.equations.chamber.insulation
   :members:

Leaf
----

.. automodule:: essm.equations.leaf

Energy Water
~~~~~~~~~~~~

.. automodule:: essm.equations.leaf.energy_water
   :members:

Physics
-------

.. automodule:: essm.equations.physics.thermodynamics
   :members:


Internals
=========

.. automodule:: essm.variables._core
   :members:
   
.. automodule:: essm.equations._core
   :members:
